@@ -1,6 +1,11 @@
 #!/usr/bin/env python
 
-__version__ = "0.0.0"
+""" TCPChan
+
+    A simple TCP multiplexing library 
+"""
+
+__version__ = "0.1.0"
 __author__ = "Frank Chang"
 __author_email__ = "frank@csie.io"
 __license__ = "BSD"
